==> lowcode-utils-1.3.7.tgz: package/es/create-icon.js <==
import _extends from "@babel/runtime/helpers/extends";
import { isValidElement, createElement, cloneElement } from 'react';
import { createFromIconfontCN } from '@ant-design/icons';
import { isReactComponent } from './is-react';
import { isESModule } from './is-es-module';
import { SizePresets } from './svg-icon';
import { isObject } from 'lodash';
var LowcodeEngineIcon;
document.addEventListener('DOMContentLoaded', function () {
  // console.log('3 seconds passed');
  LowcodeEngineIcon = createFromIconfontCN({
    scriptUrl: '//at.alicdn.com/t/c/font_4742850_ftjdvki4rx.js' // 在 iconfont.cn 上生成
  });
});
var URL_RE = /^(https?:)\/\//i;
export function createIcon(icon, props) {
  var _icon5, _icon7;
  if (!icon) {
    return null;
  }
  if (isESModule(icon)) {
    icon = icon["default"];
  }
  var style = {
    fontSize: 16
  };
  if (props !== null && props !== void 0 && props.size) {
    var _icon;
    if (props !== null && props !== void 0 && props.size) {
      if (SizePresets.hasOwnProperty(props === null || props === void 0 ? void 0 : props.size)) {
        style.fontSize = SizePresets[props === null || props === void 0 ? void 0 : props.size];
      } else {
        style.fontSize = props === null || props === void 0 ? void 0 : props.size;
      }
    } else if (isObject(icon) && (_icon = icon) !== null && _icon !== void 0 && _icon.size) {
      var _icon2;
      if (SizePresets.hasOwnProperty((_icon2 = icon) === null || _icon2 === void 0 ? void 0 : _icon2.size)) {
        var _icon3;
        style.fontSize = SizePresets[(_icon3 = icon) === null || _icon3 === void 0 ? void 0 : _icon3.size];
      } else {
        var _icon4;
        style.fontSize = (_icon4 = icon) === null || _icon4 === void 0 ? void 0 : _icon4.size;
      }
    }
  }
  if (isObject(props) && isObject(props === null || props === void 0 ? void 0 : props.style)) {
    style = _extends({}, props === null || props === void 0 ? void 0 : props.style, style);
  } else if (isObject(icon) && isObject((_icon5 = icon) === null || _icon5 === void 0 ? void 0 : _icon5.style)) {
    var _icon6;
    style = _extends({}, (_icon6 = icon) === null || _icon6 === void 0 ? void 0 : _icon6.style, style);
  }
  if (typeof icon === 'string') {
    if (URL_RE.test(icon)) {
      return /*#__PURE__*/createElement('img', _extends({
        src: icon,
        "class": props === null || props === void 0 ? void 0 : props.className
      }, props));
    }
    return /*#__PURE__*/React.createElement(LowcodeEngineIcon, _extends({
      type: 'icon-' + icon
    }, props, {
      style: style
    }));
  }
  if (/*#__PURE__*/isValidElement(icon)) {
    return /*#__PURE__*/cloneElement(icon, _extends({}, props));
  }
  if (isReactComponent(icon)) {
    return /*#__PURE__*/createElement(icon, _extends({
      "class": props === null || props === void 0 ? void 0 : props.className
    }, props));
  }
  return /*#__PURE__*/React.createElement(LowcodeEngineIcon, _extends({}, icon, {
    type: 'icon-' + ((_icon7 = icon) === null || _icon7 === void 0 ? void 0 : _icon7.type)
  }, props, {
    style: style
  }));
}

==> lowcode-utils-2.0.2.tgz: package/es/create-icon.js <==
import _extends from "@babel/runtime/helpers/extends";
import { isValidElement, createElement, cloneElement } from 'react';
import { createFromIconfontCN } from '@ant-design/icons';
import { isReactComponent } from './is-react';
import { isESModule } from './is-es-module';
import { SizePresets } from './svg-icon';
import { isObject } from 'lodash';
var LowcodeEngineIcon;
document.addEventListener('DOMContentLoaded', function () {
  // console.log('3 seconds passed');
  LowcodeEngineIcon = createFromIconfontCN({
    scriptUrl: '//at.alicdn.com/t/c/font_4742850_1i9u9jf4h66.js' // 在 iconfont.cn 上生成
  });
});
function isIconConfig(icon) {
  return isObject(icon) && ('type' in icon || 'size' in icon || 'style' in icon);
}
var URL_RE = /^(https?:)\/\//i;
export function createIcon(icon, props) {
  var _icon5, _icon7;
  if (!icon) {
    return null;
  }
  if (isESModule(icon)) {
    icon = icon["default"];
  }
  var style = {
    fontSize: 16
  };
  if (props !== null && props !== void 0 && props.size) {
    var _icon;
    if (props !== null && props !== void 0 && props.size) {
      if (SizePresets.hasOwnProperty(props === null || props === void 0 ? void 0 : props.size)) {
        style.fontSize = SizePresets[props === null || props === void 0 ? void 0 : props.size];
      } else {
        style.fontSize = props === null || props === void 0 ? void 0 : props.size;
      }
    } else if (isIconConfig(icon) && (_icon = icon) !== null && _icon !== void 0 && _icon.size) {
      var _icon2;
      if (SizePresets.hasOwnProperty((_icon2 = icon) === null || _icon2 === void 0 ? void 0 : _icon2.size)) {
        var _icon3;
        style.fontSize = SizePresets[(_icon3 = icon) === null || _icon3 === void 0 ? void 0 : _icon3.size];
      } else {
        var _icon4;
        style.fontSize = (_icon4 = icon) === null || _icon4 === void 0 ? void 0 : _icon4.size;
      }
    }
  }
  if (isObject(props) && isObject(props === null || props === void 0 ? void 0 : props.style)) {
    style = _extends({}, props === null || props === void 0 ? void 0 : props.style, style);
  } else if (isIconConfig(icon) && isObject((_icon5 = icon) === null || _icon5 === void 0 ? void 0 : _icon5.style)) {
    var _icon6;
    style = _extends({}, (_icon6 = icon) === null || _icon6 === void 0 ? void 0 : _icon6.style, style);
  }
  if (typeof icon === 'string') {
    if (URL_RE.test(icon)) {
      return /*#__PURE__*/createElement('img', _extends({
        src: icon,
        className: props === null || props === void 0 ? void 0 : props.className
      }, props));
    }
    return /*#__PURE__*/React.createElement(LowcodeEngineIcon, _extends({
      type: 'icon-' + icon
    }, props, {
      style: style,
      size: ""
    }));
  }
  if (/*#__PURE__*/isValidElement(icon)) {
    return /*#__PURE__*/cloneElement(icon, _extends({}, props));
  }
  if (isReactComponent(icon)) {
    return /*#__PURE__*/createElement(icon, props);
  }
  return /*#__PURE__*/React.createElement(LowcodeEngineIcon, _extends({}, icon, {
    type: 'icon-' + ((_icon7 = icon) === null || _icon7 === void 0 ? void 0 : _icon7.type)
  }, props, {
    style: style
  }));
}
